<?php

namespace App\Services\Client;

use App\Models\AgentConfig;
use App\Models\AgentInfo;
use App\Models\CoachConfig;
use App\Models\CoachSchedule;
use App\Models\CoachUser;
use App\Models\Coupon;
use App\Models\MemberUser;
use App\Models\Order;
use App\Models\OrderGrabRecord;
use App\Models\OrderRecord;
use App\Models\Project;
use App\Models\SysConfig;
use App\Models\User;
use App\Models\WalletRefundRecord;
use Exception;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Facades\DB;
use Illuminate\Support\Facades\Log;

class OrderService
{
    protected AgentService $agentService;

    protected ProjectService $projectService;

    public function __construct(
        AgentService $agentService,
        ProjectService $projectService
    ) {
        $this->agentService = $agentService;
        $this->projectService = $projectService;
    }

    /**
     * 订单初始化
     */
    public function initialize(int $userId, array $data): array
    {
        $user = MemberUser::find($userId);

        if (! $user) {
            throw new Exception('用户不存在');
        }

        if ($user->state != 'enable') {
            throw new Exception('用户状态异常');
        }

        // 查询用户钱包
        $wallet = $user->wallet;

        // 查询默认地址
        $address = $user->address;

        $areaCode = $address ? $address->area_code : $data['area_code'];

        // 查询技师数据
        $coach = CoachUser::where('state', 'enable')
            ->whereHas('info', function ($query) {
                $query->where('state', 'approved');
            })
            ->whereHas('real', function ($query) {
                $query->where('state', 'approved');
            })
            ->whereHas('qual', function ($query) {
                $query->where('state', 'approved');
            })
            ->with(['info:id,nickname,avatar,gender'])
            ->find($data['coach_id']);

        if (! $coach) {
            throw new Exception('技师不存在');
        }

        // 查询技师排班
        // $schedule = CoachSchedule::where('coach_id', $coachId)
        //     ->where('date', date('Y-m-d'))
        //     ->first();

        // // 查询用户优惠券
        // $coupons = Coupon::where('user_id', $userId)
        //     ->where('state', 'enable')
        //     ->where('expire_time', '>', now())
        //     ->get();

        // 获取项目详情
        $project = $this->projectService->getProjectDetail($data['project_id'], $areaCode);

        // 计算订单金额
        $amounts = $this->calculateOrderAmount($userId, $address?->id, $data['coach_id'], $data['project_id'], $project?->agent_id);

        return [
            'wallet' => $wallet,
            'coach' => $coach,
            'project' => $project,
            'address' => $address,
            // 'schedule' => $schedule,
            'amounts' => $amounts,
            // 'coupons' => $coupons
        ];
    }

    /**
     * 创建订单
     */
    public function createOrder(int $userId, array $data): array
    {
        try {
            return DB::transaction(function () use ($userId, $data) {
                // 1. 参数校验
                $user = MemberUser::where('id', $userId)
                    ->where('state', 'enable')
                    ->firstOrFail();

                $project = Project::where('id', $data['project_id'])
                    ->where('state', 'enable')
                    ->firstOrFail();

                // 2. 创建订单
                $orderType = isset($data['order_id']) ? 'add_time' : 'normal';

                if ($orderType == 'normal') {
                    $coach = $this->validateCoach($data['coach_id']);
                } else {
                    $originalOrder = $this->getOriginalOrder($user, $data['order_id']);
                    $data = $this->prepareAddTimeData($originalOrder, $data);
                }

                $address = $user->addresses()
                    ->where('id', $data['address_id'])
                    ->firstOrFail();

                // 计算订单金额
                $amounts = $this->calculateOrderAmount($userId, $address->id, $data['coach_id'], $data['project_id'], $project->agent_id, $data['use_balance'] ?? false);

                // 创建订单记录
                $order = $this->createOrderRecord($userId, $data, $orderType, $address, $amounts);

                // 余额支付处理
                if ($order->payment_type == 'balance') {
                    $this->handleBalancePayment($user, $order, $orderType);
                }

                return [
                    'order_id' => $order->id,
                    'payment_type' => $order->payment_type,
                ];
            });
        } catch (Exception $e) {
            Log::error('创建订单失败:', [
                'message' => $e->getMessage(),
                'user_id' => $userId,
                'data' => $data,
            ]);
            throw $e;
        }
    }

    // 提取方法：验证技师
    private function validateCoach($coachId): CoachUser
    {
        $coach = CoachUser::where('id', $coachId)
            ->where('state', 'enable')
            ->whereHas('info', fn ($q) => $q->where('state', 'approved'))
            ->whereHas('qual', fn ($q) => $q->where('state', 'approved'))
            ->whereHas('real', fn ($q) => $q->where('state', 'approved'))
            ->firstOrFail();

        return $coach;
    }

    // 提取方法：获取原始订单
    private function getOriginalOrder($user, $orderId): Order
    {
        $originalOrder = $user->orders->where('id', $orderId)
            ->whereIn('state', ['service_ing', 'service_end'])
            ->firstOrFail();

        return $originalOrder;
    }

    // 提取方法：准备加钟订单数据
    private function prepareAddTimeData($originalOrder, $data): array
    {
        if ($originalOrder->state == 'service_ing') {
            $startTime = now();
        } else {
            $startTime = now();
        }

        return [
            ...$data,
            'order_id' => $data['order_id'],
            'address_id' => $originalOrder->address_id,
            'service_time' => $startTime,
            'coach_id' => $originalOrder->coach_id,
        ];
    }

    // 提取方法：创建订单记录
    private function createOrderRecord($userId, $data, $orderType, $address, $amounts): Order
    {
        $order = new Order;
        $order->user_id = $userId;
        $order->project_id = $data['project_id'];
        $order->coach_id = $data['coach_id'];
        $order->type = $orderType;
        $order->state = 'wait_pay';
        $order->source = 'platform';
        $order->total_amount = $amounts->total_amount;
        $order->balance_amount = $amounts->balance_amount;
        $order->pay_amount = $amounts->pay_amount;
        $order->project_amount = $amounts->project_amount;
        $order->traffic_amount = $orderType == 'add_time' ? 0 : $amounts->delivery_fee;
        $order->payment_type = ($data['use_balance'] && $amounts->pay_amount == 0) ? 'balance' : null;
        $order->service_time = $data['service_time'];
        $order->address_id = $data['address_id'];
        $order->longitude = $address->longitude;
        $order->latitude = $address->latitude;
        $order->location = $address->location;
        $order->address = $address->address;
        $order->area_code = $address->area_code;
        $order->save();

        OrderRecord::create([
            'order_id' => $order->id,
            'object_id' => $userId,
            'object_type' => MemberUser::class,
            'state' => $orderType == 'add_time' ? 'add_time' : 'create',
            'remark' => $orderType == 'add_time' ? '加钟订单' : '创建订单',
        ]);

        return $order;
    }

    // 提取方法：处理余额支付
    private function handleBalancePayment($user, $order, $orderType): void
    {
        $order->state = $orderType == 'normal' ? 'wait_receive' : 'service_ing';
        $order->save();

        OrderRecord::create([
            'order_id' => $order->id,
            'object_id' => $user->id,
            'object_type' => MemberUser::class,
            'state' => 'pay',
            'remark' => '余额支付',
        ]);

        $user->wallet->decrement('total_balance', $order->balance_amount);
        $user->wallet->decrement('available_balance', $order->balance_amount);
        $user->wallet->save();
    }

    /**
     * 取消订单
     */
    public function cancelOrder(int $userId, int $orderId): array
    {
        return DB::transaction(function () use ($userId, $orderId) {
            try {
                $user = MemberUser::where('id', $userId)->firstOrFail();
                $order = $user->orders()->find($orderId);

                if (! $order) {
                    throw new Exception('订单不存在');
                }

                // 判断订单状态
                if ($order->state == 'wait_receive') { // 已接单
                    // 扣除20%费用
                    $deductAmount = ($order->payment_amount + $order->balance_amount - $order->traffic_amount) * 0.2;
                    $this->handleRefund($user, $order, $deductAmount, false);
                } elseif ($order->state == 'on_the_way') { // 已出发
                    // 扣除50%费用并扣除路费
                    $deductAmount = ($order->payment_amount + $order->balance_amount - $order->traffic_amount) * 0.5;
                    $this->handleRefund($user, $order, $deductAmount, true);
                } elseif ($order->state == 'wait_pay') {
                    // 待支付状态直接取消,无需退款
                } else {
                    throw new Exception('当前订单状态不允许取消');
                }

                // 添加订单取消记录
                OrderRecord::create([
                    'order_id' => $orderId,
                    'object_id' => $userId,
                    'object_type' => MemberUser::class,
                    'state' => 'cancel',
                    'remark' => '用户取消订单',
                ]);

                // 修改订单状态
                $order->state = 'cancel';
                $order->save();

                return ['message' => '订单已取消'];
            } catch (Exception $e) {
                Log::error('取消订单失败:', [
                    'message' => $e->getMessage(),
                    'user_id' => $userId,
                    'order_id' => $orderId,
                ]);
                throw $e;
            }
        });
    }

    /**
     * 处理退款
     */
    private function handleRefund(MemberUser $user, Order $order, float $deductAmount, bool $deductTrafficFee): void
    {
        // 关键操作：计算实际退款金额
        $refundAmount = $order->payment_amount + $order->balance_amount;
        if ($deductTrafficFee) {
            $refundAmount -= $order->traffic_amount;
            // TODO: 记录技师路费收入
        }
        $refundAmount -= $deductAmount;

        // 优先从余额支付金额中扣除
        $balanceRefund = min($order->balance_amount, $refundAmount);
        if ($balanceRefund > 0) {
            $this->createRefundRecords($user, $order, $balanceRefund);
        }

        // 剩余退款金额从支付金额中退还
        $paymentRefund = $refundAmount - $balanceRefund;
        if ($paymentRefund > 0) {
            $this->createRefundRecords($user, $order, $paymentRefund, 'payment');
        }

        // 记录平台收入
        if ($deductAmount > 0) {
            // TODO: 添加平台收入记录
            // PlatformIncome::create([...]);
        }
    }

    // 提取方法：创建退款记录
    private function createRefundRecords($user, $order, $amount, $type = 'balance'): void
    {
        $refundMethod = $type;
        $remark = $type == 'balance' ? '订单取消退还余额' : '订单取消退还支付金额';

        $refundRecord = $user->wallet->refundRecords()->create([
            'refund_method' => $refundMethod,
            'total_refund_amount' => $order->payment_amount + $order->balance_amount,
            'actual_refund_amount' => '0.00',
            'wallet_balance_refund_amount' => $type == 'balance' ? $amount : '0.00',
            'recharge_balance_refund_amount' => '0.00',
            'remark' => $remark,
            'order_id' => $order->id,
        ]);

        $user->wallet->transRecords()->create([
            'amount' => $amount,
            'owner_type' => get_class($refundRecord),
            'owner_id' => $refundRecord->id,
            'remark' => $remark,
            'trans_type' => 'income',
            'storage_type' => 'balance',
            'before_balance' => $user->wallet->total_balance,
            'after_balance' => $user->wallet->total_balance + $amount,
            'before_recharge_balance' => '0.00',
            'after_recharge_balance' => '0.00',
            'trans_time' => now(),
            'state' => 'success',
        ]);

        $user->wallet->increment('total_balance', $amount);
        $user->wallet->increment('available_balance', $amount);
        $user->wallet->save();
    }

    /**
     * 结束订单
     */
    public function finishOrder(int $userId, int $orderId): array
    {
        return DB::transaction(function () use ($userId, $orderId) {
            try {
                // 关键操作：参数校验
                $order = Order::where('user_id', $userId)
                    ->where('id', $orderId)
                    ->where('state', 'service_ing') // 订单状态必须是服务中
                    ->firstOrFail();

                if (! $order) {
                    throw new Exception('订单不能结束');
                }

                // 关键操作：创建订单历史记录
                OrderRecord::create([
                    'order_id' => $orderId,
                    'object_id' => $userId,
                    'object_type' => MemberUser::class,
                    'state' => 'finish',
                    'remark' => '服务完成',
                ]);

                // 关键操作：修改订单状态为服务结束
                $order->state = 'service_end';
                $order->save();

                return ['message' => '订单已完成'];
            } catch (Exception $e) {
                Log::error('结束订单失败:', [
                    'message' => $e->getMessage(),
                    'user_id' => $userId,
                    'order_id' => $orderId,
                ]);
                throw $e;
            }
        });
    }

    /**
     * 确认技师离开
     */
    public function confirmLeave(int $userId, int $orderId): array
    {
        return DB::transaction(function () use ($userId, $orderId) {
            try {
                // 1. 参数校验
                $order = Order::where('user_id', $userId)
                    ->where('id', $orderId)
                    ->where('state', 'service_end') // 订单状态必须是服务结束
                    ->firstOrFail();

                if (! $order) {
                    throw new Exception('订单不能撤离');
                }

                // 2. 添加订单撤离记录
                OrderRecord::create([
                    'order_id' => $orderId,
                    'object_id' => $userId,
                    'object_type' => MemberUser::class,
                    'state' => 'leave',
                    'remark' => '技师已离开',
                ]);

                // 3. 修改订单状态为撤离
                $order->state = 'leave';
                $order->save();

                return ['message' => '已确认技师离开'];
            } catch (Exception $e) {
                Log::error('确认技师离开失败:', [
                    'message' => $e->getMessage(),
                    'user_id' => $userId,
                    'order_id' => $orderId,
                ]);
                throw $e;
            }
        });
    }

    /**
     * 获取订单列表
     */
    public function getOrderList(int $user_id): \Illuminate\Contracts\Pagination\LengthAwarePaginator
    {
        $user = MemberUser::find($user_id);

        return $user->orders()
            ->with([
                'coach.info:id,nickname,avatar,gender',
            ])
            ->orderBy('created_at', 'desc')
            ->paginate(10);
    }

    /**
     * 获取订单详情
     */
    public function getOrderDetail(int $userId, int $orderId): Order
    {
        $user = MemberUser::find($userId);

        return $user->orders()->with([
            'coach.info:id,nickname,avatar,gender',
            'records' => function ($query) {
                $query->orderBy('created_at', 'asc');
            },
        ])
            ->firstOrFail();
    }

    /**
     * 订单退款
     */
    public function refundOrder(int $orderId): array
    {
        // 使用 Auth::user() 获取用户对象
        $user = Auth::user();

        return DB::transaction(function () use ($orderId, $user) {
            // 查询并锁定订单
            $order = Order::where('id', $orderId)
                ->where('user_id', $user->id)
                ->where('state', 'pending')
                ->lockForUpdate()
                ->firstOrFail();

            // 更新订单状态
            $order->state = 'refunded';
            $order->save();

            // 添加订单记录
            OrderRecord::create([
                'order_id' => $orderId,
                'object_id' => $user->id,
                'object_type' => 'user',
                'state' => 'refund',
                'remark' => '订单退款',
            ]);

            // 创建退款记录
            WalletRefundRecord::create([
                'order_id' => $orderId,
                'user_id' => $user->id,
                'amount' => $order->total_amount,
                'state' => 'success',
            ]);

            return ['message' => '退款成功'];
        });
    }

    /**
     * 获取代理商配置
     */
    public function getAgentConfig(int $agentId): array
    {
        $agent = AgentInfo::where('id', $agentId)
            ->where('state', 'enable')
            ->firstOrFail();

        // $config = AgentConfig::where('agent_id', $agentId)->firstOrFail();

        return [
            // 'min_distance' => $config->min_distance,
            // 'min_fee' => $config->min_fee,
            // 'per_km_fee' => $config->per_km_fee
        ];
    }

    /**
     * 获取技师配置
     */
    public function getCoachConfig(int $coachId): array
    {
        $coach = CoachUser::where('id', $coachId)
            ->where('state', 'enable')
            ->where('auth_state', 'passed')
            ->firstOrFail();

        // $config = CoachConfig::where('coach_id', $coachId)->firstOrFail();

        return [
            // 'delivery_fee_type' => $config->delivery_fee_type,
            // 'charge_delivery_fee' => $config->charge_delivery_fee
        ];
    }

    /**
     * 计算路费金额
     *
     * @param  int  $coachId  技师ID
     * @param  int  $projectId  项目ID
     * @param  int|null  $agentId  代理商ID
     * @param  float  $distance  距离(公里)
     * @return float 路费金额
     *
     * @throws Exception
     */
    public function calculateDeliveryFee(
        int $coachId,
        int $projectId,
        ?int $agentId,
        float $distance
    ): float {
        try {
            // 1. 校验技师
            $coach = CoachUser::where('state', 'enable')
                ->whereHas('info', fn ($q) => $q->where('state', 'approved'))
                ->whereHas('real', fn ($q) => $q->where('state', 'approved'))
                ->whereHas('qual', fn ($q) => $q->where('state', 'approved'))
                ->with(['projects' => fn ($q) => $q->where('project_id', $projectId)])
                ->find($coachId);

            abort_if(! $coach, 404, '技师不存在或状态异常');

            // 2. 校验技师项目
            $coachProject = $coach->projects->first();

            abort_if(! $coachProject, 404, '技师项目不存在');

            // 3. 判断是否免收路费
            if ($coachProject->traffic_fee_type == 'free') {
                return 0;
            }

            // 4. 获取路费配置
            $config = $this->getDeliveryFeeConfig($agentId);

            abort_if(! $config, 404, '路费配置不存在');

            // 5. 计算路费
            $fee = $this->calculateFee($distance, $config);

            // 6. 判断是否往返
            return $coachProject->delivery_fee_type == 'round_trip'
                ? bcmul($fee, '2', 2)
                : $fee;

        } catch (Exception $e) {
            Log::error(__CLASS__.'->'.__FUNCTION__.'计算路费失败:', [
                'message' => $e->getMessage(),
                'coach_id' => $coachId,
                'project_id' => $projectId,
                'agent_id' => $agentId,
                'distance' => $distance,
                'trace' => $e->getTraceAsString(),
            ]);
            throw $e;
        }
    }

    /**
     * 获取路费配置
     */
    private function getDeliveryFeeConfig(?int $agentId): ?object
    {
        // 优先获取代理商配置
        if ($agentId) {
            $agent = AgentInfo::where('state', 'enable')
                ->with(['projectConfig'])
                ->find($agentId);

            if ($agent && $agent->projectConfig) {
                return $agent->projectConfig;
            }
        }

        // 获取系统配置
        return SysConfig::where('key', 'delivery_fee')->first();
    }

    /**
     * 计算路费
     */
    private function calculateFee(float $distance, object $config): float
    {
        // 最小距离内按起步价计算
        if ($distance <= $config->min_distance) {
            return (float) $config->min_fee;
        }

        // 超出最小距离部分按每公里费用计算
        $extraDistance = bcsub($distance, $config->min_distance, 2);
        $extraFee = bcmul($extraDistance, $config->per_km_fee, 2);

        return bcadd($config->min_fee, $extraFee, 2);
    }

    /**
     * 计算订单金额
     *
     * @param  int  $userId  用户ID
     * @param  int  $addressId  地址ID
     * @param  int  $coachId  技师ID
     * @param  int  $projectId  项目ID
     * @param  int  $agentId  代理商ID
     * @param  bool  $useBalance  是否使用余额
     * @param  float  $distance  距离
     *
     * @throws Exception
     */
    public function calculateOrderAmount(
        int $userId,
        int $addressId,
        int $coachId,
        int $projectId,
        ?int $agentId = null,
        bool $useBalance = false,
        float $distance = 0
    ): array {
        try {
            // 1. 参数校验
            $user = MemberUser::find($userId);
            abort_if(! $user || $user->state != 'enable', 404, '用户不存在或状态异常');

            // 2. 查询技师项目
            $coach = CoachUser::where('state', 'enable')
                ->whereHas('info', fn ($q) => $q->where('state', 'approved'))
                ->whereHas('real', fn ($q) => $q->where('state', 'approved'))
                ->whereHas('qual', fn ($q) => $q->where('state', 'approved'))
                ->find($coachId);

            abort_if(! $coach, 404, '技师不存在或状态异常');

            $coachProject = $coach->projects()
                ->where('state', 'enable')
                ->where('project_id', $projectId)
                ->first();

            abort_if(! $coachProject, 404, '技师项目不存在');

            // 3. 查询基础项目
            $project = Project::where('id', $projectId)
                ->where('state', 'enable')
                ->first();

            abort_if(! $project, 404, '项目不存在或状态异常');

            // 4. 计算距离
            if ($distance <= 0) {
                $address = $user->addresses()->findOrFail($addressId);
                $coachService = app(CoachService::class);
                $coachDetail = $coachService->getCoachDetail($coachId, $address->latitude, $address->longitude);
                $distance = $coachDetail['distance'] ?? 0;
            }

            // 5. 获取项目价格
            $projectAmount = $this->getProjectPrice($project, $agentId, $projectId);

            // 6. 计算路费
            $deliveryFee = $this->calculateDeliveryFee($coachId, $projectId, $agentId, $distance);

            // 7. 计算优惠券金额
            $couponAmount = $this->calculateCouponAmount();

            // 8. 计算总金额
            $totalAmount = bcadd($projectAmount, $deliveryFee, 2);
            $totalAmount = bcsub($totalAmount, $couponAmount, 2);
            $totalAmount = max(0, $totalAmount);

            // 9. 计算余额支付金额
            $balanceAmount = 0;
            $payAmount = $totalAmount;

            if ($useBalance && $totalAmount > 0) {
                $wallet = $user->wallet;
                abort_if(! $wallet, 404, '用户钱包不存在');

                if ($wallet->available_balance >= $totalAmount) {
                    $balanceAmount = $totalAmount;
                    $payAmount = 0;
                } else {
                    $balanceAmount = $wallet->available_balance;
                    $payAmount = bcsub($totalAmount, $balanceAmount, 2);
                }
            }

            return [
                'total_amount' => $totalAmount,
                'balance_amount' => $balanceAmount,
                'pay_amount' => $payAmount,
                'coupon_amount' => $couponAmount,
                'project_amount' => $projectAmount,
                'delivery_fee' => $deliveryFee,
            ];

        } catch (Exception $e) {
            Log::error(__CLASS__.'->'.__FUNCTION__.'计算订单金额失败:', [
                'message' => $e->getMessage(),
                'user_id' => $userId,
                'project_id' => $projectId,
                'trace' => $e->getTraceAsString(),
            ]);
            throw $e;
        }
    }

    /**
     * 获取项目价格
     */
    private function getProjectPrice($project, ?int $agentId, int $projectId): float
    {
        $price = $project->price;

        if ($agentId) {
            $agent = AgentInfo::where('state', 'enable')->find($agentId);
            if ($agent) {
                $agentProject = $agent->projects()
                    ->where('state', 'enable')
                    ->where('project_id', $projectId)
                    ->first();

                if ($agentProject) {
                    $price = $agentProject->price;
                }
            }
        }

        return (float) $price;
    }

    /**
     * 计算优惠券金额
     */
    private function calculateCouponAmount(): float
    {
        $couponAmount = 0;
        if (request()->has('coupon_id')) {
            // TODO: 优惠券逻辑
        }

        return $couponAmount;
    }

    /**
     * 计算支付金额分配
     */
    private function calculatePaymentAmounts($user, float $totalAmount, bool $useBalance): array
    {
        $balanceAmount = 0;
        $payAmount = $totalAmount;

        if ($useBalance) {
            $wallet = $user->wallet;
            if (! $wallet) {
                throw new Exception('用户钱包不存在');
            }

            if ($wallet->available_balance >= $totalAmount) {
                $balanceAmount = $totalAmount;
                $payAmount = 0;
            } else {
                $balanceAmount = $wallet->available_balance;
                $payAmount = bcsub($totalAmount, $balanceAmount, 2);
            }
        }

        return [$balanceAmount, $payAmount];
    }

    /**
     * 指定技师
     */
    public function assignCoach(int $userId, int $orderId, int $coachId): bool
    {
        return DB::transaction(function () use ($userId, $orderId, $coachId) {
            try {
                // 参数校验
                $user = MemberUser::where('id', $userId)
                    ->where('state', 'enable')
                    ->firstOrFail();

                $order = Order::where('id', $orderId)
                    ->where('user_id', $userId)
                    ->whereIn('state', [0, 1, 6])
                    ->firstOrFail();

                $coach = $this->validateCoach($coachId);

                // 修改订单
                $order->coach_id = $coachId;
                if ($order->state == 'created') {
                    $amounts = $this->calculateOrderAmount(
                        $userId,
                        $order->address_id,
                        $coachId,
                        $order->project_id,
                        $order->agent_id,
                        $order->payment_type === 'balance'
                    );

                    $order->total_amount = $amounts->total_amount;
                    $order->balance_amount = $amounts->balance_amount;
                    $order->pay_amount = $amounts->pay_amount;
                    $order->coupon_amount = $amounts->coupon_amount;
                    $order->project_amount = $amounts->project_amount;
                    $order->delivery_fee = $amounts->delivery_fee;

                    if ($order->payment_type === 'balance') {
                        $order->state = 'paid';
                    }
                }
                if ($order->state == 'paid') {
                    $order->state = 'assigned';
                }
                $order->save();

                // 创建订单历史
                OrderRecord::create([
                    'order_id' => $order->id,
                    'type' => 'assigned',
                    'user_id' => $userId,
                    'coach_id' => $coachId,
                ]);

                OrderRecord::create([
                    'order_id' => $order->id,
                    'type' => 'accepted',
                    'user_id' => $userId,
                    'coach_id' => $coachId,
                    'remark' => '抢单成功',
                ]);

                // 更新抢单池
                OrderGrabRecord::where('order_id', $orderId)
                    ->update(['state' => 'success', 'coach_id' => $coachId]);

                return true;
            } catch (Exception $e) {
                Log::error('分配技师失败:', [
                    'message' => $e->getMessage(),
                    'user_id' => $userId,
                    'order_id' => $orderId,
                    'coach_id' => $coachId,
                ]);
                throw $e;
            }
        });
    }
}
